import { Knex } from 'knex';
export declare type SortingParam<FullEntityRow> = {
    column: keyof FullEntityRow & string;
    order?: 'desc' | 'asc';
};
export declare type RepositoryConfig<NewEntityRow, FullEntityRow, UpdatedEntityRow> = {
    tableName: string;
    idColumn: keyof FullEntityRow & string;
    defaultOrderBy?: SortingParam<FullEntityRow>[];
    columnsForCreate?: (keyof NewEntityRow & string)[];
    columnsForUpdate?: (keyof UpdatedEntityRow & string)[];
    columnsForGetFilters?: (keyof FullEntityRow & string)[];
    columnsToFetch: (keyof FullEntityRow & string)[];
    columnsToFetchList?: (keyof FullEntityRow & string)[];
    columnsToFetchDetails?: (keyof FullEntityRow & string)[];
};
export declare class AbstractRepository<NewEntityRow extends Record<string, any> = any, FullEntityRow extends NewEntityRow = any, UpdatedEntityRow extends Record<string, any> = Partial<NewEntityRow>> {
    protected readonly knex: Knex;
    protected readonly tableName: string;
    protected readonly columnsToFetch: string[];
    protected readonly columnsToFetchList: string[];
    protected readonly columnsToFetchDetails: string[];
    protected readonly idColumn: string;
    protected readonly defaultOrderBy?: SortingParam<FullEntityRow>[];
    private readonly columnsForCreate;
    private readonly columnsForGetFilters?;
    private readonly columnsForUpdate?;
    constructor(knex: Knex, config: RepositoryConfig<NewEntityRow, FullEntityRow, UpdatedEntityRow>);
    create(newEntityRow: NewEntityRow, transactionProvider?: Knex.TransactionProvider): Promise<FullEntityRow>;
    createBulk(newEntityRows: NewEntityRow[], transactionProvider?: Knex.TransactionProvider, chunkSize?: number): Promise<FullEntityRow[]>;
    createBulkNoReturning(newEntityRows: NewEntityRow[], transactionProvider?: Knex.TransactionProvider, chunkSize?: number): Promise<void>;
    updateById(id: string | number, updatedFields: UpdatedEntityRow, transactionProvider?: Knex.TransactionProvider): Promise<FullEntityRow | undefined>;
    updateSingleByCriteria(filterCriteria: Partial<FullEntityRow>, updatedFields: UpdatedEntityRow, transactionProvider?: Knex.TransactionProvider | null): Promise<FullEntityRow>;
    updateByCriteria(filterCriteria: Partial<FullEntityRow>, updatedFields: UpdatedEntityRow, transactionProvider?: Knex.TransactionProvider | null, sorting?: SortingParam<FullEntityRow>[] | null): Promise<FullEntityRow[]>;
    getById(id: string | number, columnsToFetch?: (keyof FullEntityRow & string)[], transactionProvider?: Knex.TransactionProvider | null): Promise<FullEntityRow | undefined>;
    getByCriteria(filterCriteria?: Partial<FullEntityRow>, sorting?: SortingParam<FullEntityRow>[] | null, columnsToFetch?: (keyof FullEntityRow & string)[], transactionProvider?: Knex.TransactionProvider | null): Promise<FullEntityRow[]>;
    getSingleByCriteria(filterCriteria: Partial<FullEntityRow>, columnsToFetch?: (keyof FullEntityRow & string)[]): Promise<FullEntityRow | undefined>;
    deleteById(id: string | number, transactionProvider?: Knex.TransactionProvider): Promise<void>;
    deleteByCriteria(filterCriteria: Partial<FullEntityRow>, transactionProvider?: Knex.TransactionProvider): Promise<void>;
    createTransactionProvider(): Knex.TransactionProvider;
    commitTransaction(transactionProvider: Knex.TransactionProvider): Promise<void>;
    rollbackTransaction(transactionProvider: Knex.TransactionProvider): Promise<void>;
    getKnexOrTransaction(transactionProvider?: Knex.TransactionProvider | null): Promise<Knex>;
}
